@@ -11,8 +11,9 @@ try: import subprocess
 except ImportError: import commands
 
 def run_async(func, args=[], kwargs={}):
-  newThread = threading.Thread(target=func, args=args, kwargs=kwargs)
-  newThread.start()
+  t = threading.Thread(target=func, args=args, kwargs=kwargs)
+  t.setDaemon(True)
+  t.start()
 
 def run_shell_command_async(cmd, banner=None):
   run_async(run_shell_command, [cmd, banner])
@@ -23,6 +24,12 @@ def run_shell_command(cmd, banner=None):
   except NameError:
     os.system(cmd)
 
+def run_shell_command2(cmd, banner=None):
+  try:
+    subprocess.Popen(cmd, shell=True)
+  except NameError:
+    os.system(cmd)
+
 def get_shell_command_output(cmd):
   result = ''
   try:
